import React, {Component} from 'react';
import './YYImagePicker.css';
import {ImagePicker, Modal, List, Toast} from 'antd-mobile';
import _ from 'lodash';
import UploadFileUtils from '../../utils/UploadFileUtils';
import classnames from 'classnames';
import AuthToken from '../../utils/AuthToken';

const alert = Modal.alert;


class YYImagePicker extends Component {
    state = {
        files: this.props.files,
        scrollTop:'0',
    };

    componentDidMount() {
        let _self = this;
        if (this.props.source) {
            this.loadAttachList(this.props.source);
        }
        window.addEventListener('scroll', (val)=>{
            _self.state.scrollTop = document.documentElement.scrollTop;
        });
    }

    componentWillReceiveProps(nextProps) {
        if (this.props.source && this.props.source.sourceId != nextProps.source.sourceId) {
            this.loadAttachList(this.props.source);
        }
        if (JSON.stringify(nextProps.files) !== JSON.stringify(this.props.files)) {
            this.setState({
                files: nextProps.files
            })
        }
    }

    loadAttachList(source) {
        let params = {
            id: source.sourceId,
            billType: source.billType,
            type: source.sourceType
        };
        let that = this;
        if (source.sourceId && source.sourceType && source.billType) {
            UploadFileUtils.loadAttachList(params, function (data) {
                if (data.length > 0) {
                    that.setState({
                        files: data
                    })
                }
            })
        }
    }

    onChange = (files, type, index) => {
        if (type == 'add') {
            console.log(files, 'onChange')
            // this.props.onChange(files)
        } else if (type == 'remove') {
            this.deleteFile(index);
        } else {
            console.log('上传错误！')
        }
    };
//删除文件
    deleteFile = (index) => {
        let that = this;
        const alertInstance = alert('删除', '删除后不可恢复!', [
            {
                text: '取消', onPress: () => {
                alertInstance.close();
            }, style: 'default'
            },
            {
                text: '确定', onPress: () => {
                if (this.props.source.sourceType) {
                    let params = {
                        id: this.props.source.sourceId,
                        billType: this.props.source.billType,
                        sourceType: this.props.source.sourceType,
                        attachIds: this.state.files[index].gid
                    };
                    UploadFileUtils.delAttach(params, () => {
                        that.setState({
                            files: that.state.files.filter((e, i) => i != index),
                        }, () => {
                            if (_.isFunction(that.props.onChange)) {
                                that.props.onChange(this.state.files);
                            }
                        });
                    });
                } else {
                    this.setState({
                        files: that.state.files.filter((e, i) => i != index),
                    }, () => {
                        if (_.isFunction(that.props.onChange)) {
                            that.props.onChange(this.state.files);
                        }
                    })
                }
            }
            },
        ]);
    };
    onAddImageClick = (e) => {
        const {orderQuality, orderWidth,camera,picture} = this.props;
        let that = this;
        e.preventDefault();//阻止触发onChange事件！
        let params = {
            billType: this.props.source.billType,
            sourceType: this.props.source.sourceType,
            sourceId: this.props.source.sourceId,
            userId: AuthToken.getUserId(),
            userName: AuthToken.getUserName(),
            camera:camera,
            picture:picture,
            file:this.props.file,
            multiple:this.props.multiple,
            upload:this.props.upload,
        };
        if (orderQuality) {
            params.orderQuality = orderQuality;
        }
        if (orderWidth) {
            params.orderWidth = orderWidth;
        }
        var file = {};
        if (window.YYPlugin) {
            window.YYPlugin.call("CommonPlugin", "postFile", params, function success(result) {
                //是否为多选模式
                if(that.props.multiple){
                    if(result.success == "1"&&result.data&&result.data.length>0){
                        let backData = [];
                        result.data.map((item)=>{
                            let itemsFile = {};
                            itemsFile.gid = item.gid;
                            itemsFile.name = item.fileName;
                            let urlArray = item.filePath.split('.');
                            itemsFile.url = item.filePath.replace('.'+urlArray[urlArray.length-1],'_100x100.'+urlArray[urlArray.length-1]);
                            console.log(itemsFile.url);
                            itemsFile.openurl = item.filePath;
                            itemsFile.backData = item;
                            backData.push(itemsFile);
                        })
                        that.setState({
                            files: that.state.files.concat(backData),
                        }, () => {
                            if (_.isFunction(that.props.onChange)) {
                                that.props.onChange(that.state.files);
                            }
                        })
                    } else if(!result.success&& result.success!=='0'&&Object.keys(result).length!==0){
                        file.gid = result.gid;
                        file.name = result.fileName;
                        let urlArray = result.filePath.split('.');
                        file.url = result.filePath.replace('.'+urlArray[urlArray.length-1],'_100x100.'+urlArray[urlArray.length-1]);
                        console.log(file.url);
                        file.openurl = result.filePath;
                        file.backData = result;
                        that.setState({
                            files: that.state.files.concat(file),
                        }, () => {
                            if (_.isFunction(that.props.onChange)) {
                                that.props.onChange(that.state.files);
                            }
                        });
                    }
                } else {
                    file.gid = result.gid;
                    file.name = result.fileName;
                    let urlArray = result.filePath.split('.');
                    file.url = result.filePath.replace('.'+urlArray[urlArray.length-1],'_100x100.'+urlArray[urlArray.length-1]);
                    console.log(file.url);
                    file.openurl = result.filePath;
                    file.backData = result;
                    that.setState({
                        files: that.state.files.concat(file),
                    }, () => {
                        if (_.isFunction(that.props.onChange)) {
                            that.props.onChange(that.state.files);
                        }
                    });
                }
            });
        } else {
            Toast.info('请在手机上进行调试或检查yyplus的引入！')
        }
    };

    /***点击图片预览*****/
    onImageClick = (index, val) => {
        let src = this.state.files[index].openurl;
        if(src){
            let url = src.split('.');
            let params = {
                thumbnailUrl:src.replace('.'+url[url.length-1],'_355x500.'+url[url.length-1]),
                originalUrl:src
            }
            window.Bridge_YYPlugin.call("CommonPlugin", "openPic", params);
        } else {
            let Vurl =val[index].fileUrl?val[index].fileUrl.split('.'):val[index].url.split('.');
            let  realUrl=val[index].fileUrl?val[index].fileUrl:val[index].url;
            let Vparams = {
                thumbnailUrl:realUrl.replace('.'+Vurl[Vurl.length-1],'_355x500.'+Vurl[Vurl.length-1]),
                originalUrl:realUrl
            }
            window.Bridge_YYPlugin.call("CommonPlugin", "openPic", Vparams);
        }
    }

    render() {
        //所有外部props都需要定义，防止警告
        const {disabled, maxSize, label, className, orderQuality,source,camera,picture,file, orderWidth,files,  visible, selectable, ...restProps} = this.props;
        let wrapClz = classnames('yy-image-picker', (!visible && 'hidden'), className);
        let {imageDiv, openDiv} = this.state;
        return (
            <div {...restProps} className={wrapClz}>
                {label && <div className="label">{label}</div>}
                <ImagePicker
                    files={this.state.files}
                    onChange={disabled ? null : this.onChange}
                    onImageClick={this.onImageClick}
                    selectable={!disabled && this.state.files.length < maxSize}
                    onAddImageClick={this.onAddImageClick}
                />
                {openDiv && imageDiv}
            </div>
        );
    }
}

YYImagePicker.defaultProps = {
    label: '上传图片',
    maxSize: 5,
    disabled: false,
    source: {
        sourceId: '',
        billType: '',
        sourceType: '',
    },
    files: [],
    orderQuality: null,
    orderWidth: null,
    visible: true,
    selectable: true,
    camera:true,
    picture:true,
    file:false,
    multiple:false,//是否开启多选模式
    upload:'0',          //是否暂缓上传，默认不暂缓0，暂缓为1
};
module.exports = YYImagePicker;